==> tboxsdk-0.0.1.tar.gz: tboxsdk-0.0.1/tests/test_tbox_chat.py <==
import os
import sys

CWD = os.path.dirname(os.path.abspath(__file__))
SDK_PATH = os.path.dirname(CWD)

sys.path.append(SDK_PATH)

from tbox_client.tbox import TboxClient

authorization = os.getenv("HTTP_CLIENT_AUTHORIZATION")
if authorization is None:
    raise Exception("env HTTP_CLIENT_AUTHORIZATION is not set")

tbox_client = TboxClient(authorization=authorization)
# response = tbox_client.chat(appId="202504APhQ9F00382583", query="今天杭州天气怎么样？", withMeta=True)
response = tbox_client.chat(appId="202504APhQ9F00382583", query="今天杭州天气怎么样？")
for chunk in response:
    print(f"--------------------------------------------------------")
    print(f"data: {chunk}")
    print(f"--------------------------------------------------------")

# --------------------------------------------------------
# data: {'entity': {'node_type': 'output', 'execute_id': '5', 'node_name': '输出内容', 'node_id': 'OU_awwbf6'}, 'lane': 'default', 'payload': {'extraParams': {}, 'mediaType': 'text', 'requestId': '54160f67-5ffd-4e56-ae7a-ccc23f7289cf', 'sessionId': '20250523BogH28797009'}, 'type': 'header'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '今天'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '（202'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '5年05'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '月23日'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '）杭州市的天气'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '情况如下：\n\n-'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': ' 白天：'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '小雨，气温'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '约为27°C'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '，西北风1'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '-3级。'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '\n- 夜间'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '：多云，'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '气温下降到约'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '17°C，'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '依然是西北风1'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '-3级。'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '\n\n请记得带伞'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '出门，并注意温'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '差变化。'}, 'type': 'chunk'}
# --------------------------------------------------------

==> tboxsdk-0.0.2.tar.gz: tboxsdk-0.0.2/tests/test_tbox_chat.py <==
import os
import sys

CWD = os.path.dirname(os.path.abspath(__file__))
SDK_PATH = os.path.dirname(CWD)

sys.path.append(SDK_PATH)

from tboxsdk.tbox import TboxClient

authorization = os.getenv("HTTP_CLIENT_AUTHORIZATION")
if authorization is None:
    raise Exception("env HTTP_CLIENT_AUTHORIZATION is not set")

tbox_client = TboxClient(authorization=authorization)
# response = tbox_client.chat(appId="202504APhQ9F00382583", query="今天杭州天气怎么样？", withMeta=True)
response = tbox_client.chat(appId="202504APhQ9F00382583", query="今天杭州天气怎么样？", userId="1234567890")
for chunk in response:
    print(f"--------------------------------------------------------")
    print(f"data: {chunk}")
    print(f"--------------------------------------------------------")

# --------------------------------------------------------
# data: {'entity': {'node_type': 'output', 'execute_id': '5', 'node_name': '输出内容', 'node_id': 'OU_awwbf6'}, 'lane': 'default', 'payload': {'extraParams': {}, 'mediaType': 'text', 'requestId': '54160f67-5ffd-4e56-ae7a-ccc23f7289cf', 'sessionId': '20250523BogH28797009'}, 'type': 'header'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '今天'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '（202'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '5年05'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '月23日'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '）杭州市的天气'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '情况如下：\n\n-'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': ' 白天：'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '小雨，气温'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '约为27°C'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '，西北风1'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '-3级。'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '\n- 夜间'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '：多云，'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '气温下降到约'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '17°C，'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '依然是西北风1'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '-3级。'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '\n\n请记得带伞'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '出门，并注意温'}, 'type': 'chunk'}
# --------------------------------------------------------
# --------------------------------------------------------
# data: {'lane': 'default', 'payload': {'text': '差变化。'}, 'type': 'chunk'}
# --------------------------------------------------------
